@@ -208,7 +208,10 @@ impl Client {
             serde_json::from_value(resp)?;
         // Convert "result": "Failed" into API errors
         if login_resp.login.result == "Failed" {
-            Err(Error::ApiError(login_resp.login.reason))
+            Err(match login_resp.login.reason {
+                Some(reason) => Error::ApiError(reason),
+                None => Error::UnknownError("Login failed".to_string()),
+            })
         } else {
             Ok(())
         }
